pub enum TurnOutcome {
Completed,
Poisoned,
}Expand description
Result of waiting for a serialized turn.
Variants
Completed
The transition and its complete synchronous output handling finished.
Poisoned
The executor was poisoned by a transition or output-handler panic.