pub struct TurnReceipt(/* private fields */);Expand description
Completion receipt for one serialized input.
Implementations
Sourceimpl TurnReceipt
impl TurnReceipt
Sourcepub fn outcome(&self) -> Option<TurnOutcome>
pub fn outcome(&self) -> Option<TurnOutcome>
Return the outcome without blocking, if the turn has finished.
Panics
Panics if receipt synchronization was poisoned.
Sourcepub fn wait(self) -> TurnOutcome
pub fn wait(self) -> TurnOutcome
Block until the turn completes or its executor is poisoned.
Panics
Panics if receipt synchronization was poisoned.